%global gittag stable_0_7_5

Name:      eclipse-epic
Version:   0.7.5
Release:   4%{?dist}
Summary:   Perl Eclipse plug-in
License:   CPL
URL:       http://www.epic-ide.org/

Source0:   https://github.com/jploski/epic-ide/archive/%{gittag}.tar.gz
Source1:   eclipse-epic.metainfo.xml

# enable module starter and taint checking by default
Patch0:    eclipse-epic-enable-module-starter.patch
# fix build against photon, see https://github.com/jploski/epic-ide/pull/48
Patch1:    photon-build.patch

BuildArch:        noarch

# Upstream Eclipse no longer supports non-64bit arches
ExcludeArch: s390 %{arm} %{ix86}

BuildRequires:    perl-generators
BuildRequires:    tycho
BuildRequires:    antlr
BuildRequires:    jdom
BuildRequires:    gnu-regexp
BuildRequires:    brazil
Requires:         eclipse-platform
Requires:         antlr
Requires:         jdom
Requires:         gnu-regexp
Requires:         brazil
Requires:         perl-interpreter
Requires:         perl(PadWalker)
Requires:         perl(Module::Starter)
Requires:         perl(Test::Simple)
Requires:         perl(Perl::Tidy)

%description
EPIC is an open source Perl IDE based on the Eclipse platform. Features 
supported are syntax highlighting, on-the-fly syntax check, content assist, 
perldoc support, source formatter, templating support, a regular expression 
view and a Perl debugger.

%prep
%setup -q -n epic-ide-%{gittag}

%patch0
%patch1 -p1

# remove all bundled libs
find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;

# build against fedora packaged libs
build-jar-repository -s -p org.epic.lib/lib jdom antlr gnu-regexp brazil
grep -lR jdom-1.1 *         | xargs sed --in-place "s/jdom-1.1/jdom/"
grep -lR antlr-2.7.5 *      | xargs sed --in-place "s/antlr-2.7.5/antlr/"
grep -lR gnu-regexp-1.1.4 * | xargs sed --in-place "s/gnu-regexp-1.1.4/gnu-regexp/"
grep -lR brazil_mini *      | xargs sed --in-place "s/brazil_mini/brazil/"

# remove plugins we don't build
rm -rf org.epic.perleditor{.ecf,-test}

# generate poms
xmvn -o org.eclipse.tycho:tycho-pomgenerator-plugin:generate-poms \
  -DgroupId=org.epic -Dversion=%{version}

# put the source plugin together
for p in org.epic.perleditor \
         org.epic.regexp \
         org.epic.debug; do
  pver=$(grep -e '^Bundle-Version' $p/META-INF/MANIFEST.MF | cut -d' ' -f2)
  mkdir org.epic.source/src/${p}_${pver}
  pushd $p/src
  zip -r -q ../../org.epic.source/src/${p}_${pver}/src.zip *
  popd
done

# dir-shaped bundles
for p in org.epic.doc org.epic.lib org.epic.source; do
  echo "Eclipse-BundleShape: dir" >> $p/META-INF/MANIFEST.MF
done

# don't install poms
%mvn_package "::pom::" __noinstall

%build
# parse grammar for grammar parser
pushd org.epic.perleditor/src/org/epic/core/parser/
for g in `find . -name "*.g"`; do
  antlr $g
done
popd

%mvn_build -j

%install
%mvn_install

# appdata
install -m644 -D %{SOURCE1} %{buildroot}%{_datadir}/appdata/eclipse-epic.metainfo.xml

# need to recreate the symlinks to libraries that were setup in "prep"
# because for some reason the ant copy task doesn't preserve them
pushd %{buildroot}%{_datadir}/eclipse/droplets/epic/plugins/org.epic.lib_*/lib
rm *.jar
build-jar-repository -s -p . jdom antlr gnu-regexp brazil
popd

%files -f .mfiles
%license org.epic.feature.main/license.html
%{_datadir}/appdata/eclipse-epic.metainfo.xml

%changelog
* Mon Mar 18 2019 Mat Booth <mat.booth@redhat.com> - 0.7.5-4
- Restrict to same architectures as Eclipse itself

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed May 09 2018 Mat Booth <mat.booth@redhat.com> - 0.7.5-1
- Update to latest upstream release
- Fix building against photon

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.7.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Jul 13 2017 Petr Pisar <ppisar@redhat.com> - 0.7.3-2
- perl dependency renamed to perl-interpreter
  <https://fedoraproject.org/wiki/Changes/perl_Package_to_Install_Core_Modules>

* Wed May 03 2017 Mat Booth <mat.booth@redhat.com> - 0.7.3-1
- Update to latest upstream version
- Patch to allow building against Oxygen

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.57-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Mar 08 2016 Mat Booth <mat.booth@redhat.com> - 0.6.57-2
- Add appdata add-on metadata

* Sat Mar 05 2016 Mat Booth <mat.booth@redhat.com> - 0.6.57-1
- Update to upstream version 0.6.57
- Build with tycho

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.6.54-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.54-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.54-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 21 2014 Mat Booth <fedora@matbooth.co.uk> - 0.6.54-2
- Drop explicit dep on java, rhbz #1068043

* Fri Mar 21 2014 Mat Booth <fedora@matbooth.co.uk> - 0.6.54-1
- Update to upstream version 0.6.54.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.44-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 0.6.44-4
- Perl 5.18 rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.44-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.44-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Apr 19 2012 Alexander Kurtakov <akurtako@redhat.com> 0.6.44-1
- Update to upstream 0.6.44 version.
- Drop unneeded parts of the spec.

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.39-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Feb 13 2011 Mat Booth <fedora@matbooth.co.uk> 0.6.39-1
- Update to version 0.6.39.
- Fixed Bug [ 3155635 ] updating to 6.38 causes Bug #3143553
- Fixed Bug [ 3143553 ] Error in Core prohibit start of debugger or script
- Applied Patch [ 3087284 ] show perlcritic policy name in problems view
- Fixed Bug [ 3065307 ] Compilation fails on file with UTF-8 encoding
- Fixed Bug [ 3106556 ] Perl::Critic markers are not saved on exit
- Fixed Bug [ 2972523 ] Undo history size fixed at 25
- Fixed Bug [ 2931385 ] weird bracket autocompletion (Patch [ 3062529 ])
- Added some automatic hints about a workaround for Bug [ 2907155 ]
- Fixed Bug [ 2818300 ] Editor toggle breakpoint action not set up
- Applied Patch [ 2974383 ] Adds severity and other options for running Perl::Critic

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.35-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.35-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 02 2009 Mat Booth <fedora@matbooth.co.uk> 0.6.35-1
- Drop GCJ support.
- Require Perl::Tidy for code formatting.
- Update to version 0.6.35.
- Fixed Bug [ 2782469 ] Step Return very slow, ends up in overload.pm
- Fixed Bug [ 1874581 ] Outline view out of sync with comment typing/deletion

* Tue Mar 24 2009 Mat Booth <fedora@matbooth.co.uk> 0.6.33-1
- Rebuilt to omit p2 metadata.
- Updated to version 0.6.33.
- Fixed Bug [ 2609775 ] CGI debugging: Could not connect to debug port!
- Fixed Bug [ 2617018 ] Breakpoints view sorting
- Fixed Bug [ 2703403 ] Show options remain disabled in Variables view
- Fixed Bug [ 2680597 ] doesn't respect global Eclipse text editor background color
- Fixed Bug [ 2694463 ] Templates don't work anymore in 0.6.32
- Fixed Bug [ 2617016 ] Editor fails highlight. double-click.
- Fixed Bug [ 2612813 ] Editor fails highlight. Binary operators.
- Implemented Feature Request [ 2692844 ] Preference for fold column background color

* Mon Mar 16 2009 Mat Booth <fedora@matbooth.co.uk> 0.6.31-2
- Add missing dependency Test::Simple for Module::Starter integration.
- Enable Module::Starter and taint checking by default.

* Sun Mar 1 2009 Mat Booth <fedora@matbooth.co.uk> 0.6.31-1
- Updated to verion 0.6.31.
- Fixed Bug [ 2431258 ] Perl internal variables not appearing
- Fixed Bug [ 2241882 ] NPE in Perl Expression View
- Fixed Bug [ 2513003 ] epic_breakpoints raises exception in Template::Toolkit
- Fixed Bug [ 2501676 ] debugger crash
- Fixed Bug [ 2433437 ] Content-type does not enable to run/debug perl scripts
- Fixed Bug [ 2537700 ] Editor fails highlight. grep + regexp
- Fixed Bug [ 2502366 ] Content assist and typed lexicals
- Fixed Bug [ 2502358 ] Content assist and "use base"
- Applied Patch [ 2490403 ] cygwin drive prefix processing
- Implemented Feature Request [ 2431423 ] Show @_ in Variables view

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.27-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Nov 15 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.27-1
- Add Module::Starter dependency.
- Updated to verion 0.6.27.
- Fixed Bug [ 2188379 ] Global variables can not be displayed
- Fixed Bug [ 2059660 ] shift left works different than in other eclipse editors
- Implemented Feature Request [ 2204771 ] Enable variable substitution for Perl executable in prefs
- Implemented Feature Request [ 2197630 ] Display package-scope ('our') variables in debugger

* Thu Sep 04 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.25-1
- Updated to version 0.6.25.

* Wed Jul 30 2008 Andrew Overholt <overholt@redhat.com> 0.6.24-3
- Update for building with Eclipse SDK 3.4.

* Sat Jun 14 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.24-2
- Fixed package ownership of feature directory.

* Sun Jun 01 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.24-1
- Updated to version 0.6.24.

* Mon May 05 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.23-1
- Removed JDOM API patch that was moved upstream.
- Updated to version 0.6.23.

* Tue Apr 29 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.22-4
- Added missing dependency.
- Build the source plugin properly to support the "import as projects with
  source folders" feature of Eclipse.

* Sat Apr 19 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.22-3
- Use JPackage tools to create jar repositories.

* Sun Apr 13 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.22-2
- Updated package for new Eclipse plugin guidelines.

* Sun Mar 30 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.22-1
- Updated to version 0.6.22.

* Wed Feb 20 2008 Mat Booth <fedora@matbooth.co.uk> 0.6.20-1
- Updated to version 0.6.20.

* Mon Dec 24 2007 Mat Booth <fedora@matbooth.co.uk> 0.6.17-1
- Initial release.
